@@ -1,6 +1,6 @@
 /*
  * This file is part of Gnome Subtitles.
- * Copyright (C) 2006-2018 Pedro Castro
+ * Copyright (C) 2006-2019 Pedro Castro
  *
  * Gnome Subtitles is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,7 +25,6 @@ using Gtk;
 using SubLib.Core.Domain;
 using SubLib.Core.Timing;
 using System;
-using System.ComponentModel;
 using System.Text;
 
 namespace GnomeSubtitles.Core {
@@ -101,7 +100,7 @@ public class EventHandlers {
 	}
 
     public void OnFileQuit (object o, EventArgs args) {
-		Base.Ui.Quit();
+		Base.Quit();
 	}
 
 
@@ -457,8 +456,8 @@ public class EventHandlers {
 	/*	Window	*/
 
 	public void OnWindowDelete (object o, DeleteEventArgs args) {
-    	Base.Ui.Quit();
-    	args.RetVal = true;
+    	bool quit = Base.Quit();
+    	args.RetVal = !quit; //True to keep the window open
     }
 
     public void OnSizeAllocated (object o, SizeAllocatedArgs args) {
