@@ -1,6 +1,6 @@
 /*
  * This file is part of Gnome Subtitles.
- * Copyright (C) 2007-2018 Pedro Castro
+ * Copyright (C) 2007-2019 Pedro Castro
  *
  * Gnome Subtitles is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -134,7 +134,7 @@ public class PreferencesDialog : BaseDialog {
 		autoBackupSpinButton.WidthChars = 2;
 		autoBackupSpinButton.Sensitive = autoBackupEnabled;
 		autoBackupSpinButton.Value = Base.Config.BackupTime / 60; //Minutes
-		autoBackupSpinButton.Changed += OnAutoBackupTimeSpinButtonValueChanged;
+		autoBackupSpinButton.ValueChanged += OnAutoBackupTimeSpinButtonValueChanged;
 		backupBox.Add(autoBackupSpinButton);
 		
 		backupBox.Add(new Label(Catalog.GetString("minutes")));
@@ -163,7 +163,7 @@ public class PreferencesDialog : BaseDialog {
 		videoSeekRewindSpinButton.WidthChars = 4;
 		videoSeekRewindSpinButton.Value = Base.Config.VideoSeekOnChangeRewind;
 		videoSeekRewindSpinButton.Sensitive = videoSeekCheckButton.Active;
-		videoSeekRewindSpinButton.Changed += OnVideoSeekRewindSpinButtonValueChanged;
+		videoSeekRewindSpinButton.ValueChanged += OnVideoSeekRewindSpinButtonValueChanged;
 		videoSeekRewindHBox.Add(videoSeekRewindSpinButton);
 		videoSeekRewindHBox.Add(new Label(Catalog.GetString("ms before the actual start to help review new timings")));
 		
@@ -178,7 +178,7 @@ public class PreferencesDialog : BaseDialog {
 		SpinButton subtitleSplitSpinButton = new SpinButton(0, 2000, 50);
 		subtitleSplitSpinButton.WidthChars = 4;
 		subtitleSplitSpinButton.Value = Base.Config.TimingsTimeBetweenSubtitles;
-		subtitleSplitSpinButton.Changed += OnSubtitleSplitSpinButtonValueChanged;
+		subtitleSplitSpinButton.ValueChanged += OnSubtitleSplitSpinButtonValueChanged;
 		splitHBox.Add(subtitleSplitSpinButton);
 		splitHBox.Add(new Label(Catalog.GetString("ms between subtitles when inserting or splitting")));
 		
@@ -199,7 +199,7 @@ public class PreferencesDialog : BaseDialog {
 		reactionDelaySpinButton.WidthChars = 4;
 		reactionDelaySpinButton.Sensitive = reactionDelayEnabled;
 		reactionDelaySpinButton.Value = Base.Config.VideoReactionDelay;
-		reactionDelaySpinButton.Changed += OnReactionDelaySpinButtonValueChanged;
+		reactionDelaySpinButton.ValueChanged += OnReactionDelaySpinButtonValueChanged;
 		reactionDelayHBox.Add(reactionDelaySpinButton);
 
 		reactionDelayHBox.Add(new Label(Catalog.GetString("ms when setting subtitle start/end while playing the video")));
@@ -213,9 +213,9 @@ public class PreferencesDialog : BaseDialog {
 		int fixedEncoding = -1;
 		ConfigFileOpenEncodingOption fileOpenEncodingOption = Base.Config.FileOpenEncodingOption;
 		if (fileOpenEncodingOption == ConfigFileOpenEncodingOption.Specific) {
-			string encodingName = Base.Config.FileOpenEncodingFixed;
+			string encodingCode = Base.Config.FileOpenEncodingFixed;
 			EncodingDescription encodingDescription = EncodingDescription.Empty;
-			Encodings.Find(encodingName, ref encodingDescription);
+			Encodings.Find(encodingCode, ref encodingDescription);
 			fixedEncoding = encodingDescription.CodePage;
 		}
 
@@ -232,9 +232,9 @@ public class PreferencesDialog : BaseDialog {
 		int fixedEncoding = -1;
 		ConfigFileOpenFallbackEncoding fileOpenFallbackEncodingConfig = Base.Config.FileOpenFallbackEncoding;
 		if (fileOpenFallbackEncodingConfig == ConfigFileOpenFallbackEncoding.Fixed) {
-			string encodingName = Base.Config.FileOpenFallbackEncodingFixed;
+			string encodingCode = Base.Config.FileOpenFallbackEncodingFixed;
 			EncodingDescription encodingDescription = EncodingDescription.Empty;
-			Encodings.Find(encodingName, ref encodingDescription);
+			Encodings.Find(encodingCode, ref encodingDescription);
 			fixedEncoding = encodingDescription.CodePage;
 		}
 
@@ -248,9 +248,9 @@ public class PreferencesDialog : BaseDialog {
 		int fixedEncoding = -1;
 		ConfigFileSaveEncodingOption fileSaveEncodingOption = Base.Config.FileSaveEncodingOption;
 		if (fileSaveEncodingOption == ConfigFileSaveEncodingOption.Specific) {
-			string encodingName = Base.Config.FileSaveEncodingFixed;
+			string encodingCode = Base.Config.FileSaveEncodingFixed;
 			EncodingDescription encodingDescription = EncodingDescription.Empty;
-			Encodings.Find(encodingName, ref encodingDescription);
+			Encodings.Find(encodingCode, ref encodingDescription);
 			fixedEncoding = encodingDescription.CodePage;
 		}
 
@@ -308,7 +308,7 @@ public class PreferencesDialog : BaseDialog {
 		if (activeOption == ConfigFileOpenEncodingOption.Specific) {
 			EncodingDescription chosenEncoding = fileOpenEncoding.ChosenEncoding;
 			if (!chosenEncoding.Equals(EncodingDescription.Empty)) {
-				Base.Config.FileOpenEncodingFixed = chosenEncoding.Name;
+				Base.Config.FileOpenEncodingFixed = chosenEncoding.Code;
 			}
 		}
 		else {
@@ -327,7 +327,7 @@ public class PreferencesDialog : BaseDialog {
 		else {
 			EncodingDescription chosenEncoding = fileOpenFallbackEncoding.ChosenEncoding;
 			if (!chosenEncoding.Equals(EncodingDescription.Empty)) {
-				Base.Config.FileOpenFallbackEncodingFixed = chosenEncoding.Name;
+				Base.Config.FileOpenFallbackEncodingFixed = chosenEncoding.Code;
 			}
 		}
 	}
@@ -343,7 +343,7 @@ public class PreferencesDialog : BaseDialog {
 		if (activeOption == ConfigFileSaveEncodingOption.Specific) {
 			EncodingDescription chosenEncoding = fileSaveEncoding.ChosenEncoding;
 			if (!chosenEncoding.Equals(EncodingDescription.Empty)) {
-				Base.Config.FileSaveEncodingFixed = chosenEncoding.Name;
+				Base.Config.FileSaveEncodingFixed = chosenEncoding.Code;
 			}
 		}
 		else {
@@ -443,7 +443,7 @@ public class PreferencesDialog : BaseDialog {
 	private void OnSubtitleSplitSpinButtonValueChanged (object o, EventArgs args) {
 		Base.Config.TimingsTimeBetweenSubtitles = (o as SpinButton).ValueAsInt;
 	}
-
+	
 }
 
-}
+}
\ No newline at end of file
