@@ -1,6 +1,6 @@
 /*
  * This file is part of Gnome Subtitles.
- * Copyright (C) 2006-2008 Pedro Castro
+ * Copyright (C) 2006-2019 Pedro Castro
  *
  * Gnome Subtitles is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,10 +18,9 @@
  */
 
 using System.Reflection;
-using System.Runtime.CompilerServices;
 
-[assembly: AssemblyVersion("1.4.2")]
+[assembly: AssemblyVersion("1.6")]
 [assembly: AssemblyTitle ("Gnome Subtitles")]
 [assembly: AssemblyDescription ("Video subtitling for the GNOME desktop")]
-[assembly: AssemblyCopyright ("Copyright (c) 2006-2010 Pedro Castro")]
+[assembly: AssemblyCopyright ("Copyright (c) 2006-2019 Pedro Castro")]
 
