@@ -1,6 +1,6 @@
 /*
  * This file is part of Gnome Subtitles.
- * Copyright (C) 2006-2018 Pedro Castro
+ * Copyright (C) 2006-2019 Pedro Castro
  *
  * Gnome Subtitles is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,21 +18,20 @@
  */
 
 using GnomeSubtitles.Core;
-using GnomeSubtitles.Core.Command;
 using GnomeSubtitles.Dialog;
-using GnomeSubtitles.Dialog.Unmanaged;
+using GnomeSubtitles.Dialog.Message;
+using GnomeSubtitles.Execution;
 using GnomeSubtitles.Ui.Edit;
 using GnomeSubtitles.Ui.VideoPreview;
 using GnomeSubtitles.Ui.View;
 using Gtk;
-using Mono.Unix;
 using SubLib.Core.Domain;
 using SubLib.Exceptions;
 using SubLib.Util;
 using System;
 using System.IO;
-using System.Text;
 using System.Reflection;
+using System.Text;
 
 namespace GnomeSubtitles.Ui {
 
@@ -47,15 +46,23 @@ public class MainUi {
 	private Status status = null;
 
 	/* Constant strings */
-	private const string uiFilename = "MainWindow.ui";
-	private const string iconFilename = "gnome-subtitles.svg";
+	private const string uiResourceName = "MainWindow.ui";
 
 	public MainUi (EventHandlers handlers) {
-		builder = new Builder(uiFilename, Base.ExecutionContext.TranslationDomain);
-
+		builder = ReadUIContent(uiResourceName, Base.ExecutionContext.TranslationDomain);
+		
 		window = builder.GetObject("window") as Window;
-		window.Icon = new Gdk.Pixbuf(null, iconFilename);
+		
+		/* Setting the iconName and wmClass (app name) name is not necessary if a standard desktop environment is
+		 * executing the application, in which case this information is obtained from the .desktop file. This is
+		 * here just in case a non-standard environment is in place.
+		 */
+		window.IconName = Base.ExecutionContext.IconName;
+		window.SetWmclass(Base.ExecutionContext.ApplicationName, Base.ExecutionContext.ApplicationName);
+		
 		window.SetDefaultSize(Base.Config.ViewWindowWidth, Base.Config.ViewWindowHeight);
+		
+		Base.ExecutionContext.Application.AddWindow(window);
 
 		video = new Video();
 		view = new SubtitleView();
@@ -100,7 +107,7 @@ public class MainUi {
     /* Public Methods */
 
 	public static Widget GetWidget (string name) {
-			return builder.GetObject(name) as Widget;
+		return builder.GetObject(name) as Widget;
 	}
 
     /// <summary>Starts the GUI</summary>
@@ -121,24 +128,22 @@ public class MainUi {
     }
 
     /// <summary>Quits the application.</summary>
-    public void Quit () {
-		if (ToCloseAfterWarning())
-			Base.Quit();
+    public bool Quit () {
+		if (ToCloseAfterWarning()) {
+			Video.Quit();
+			window.Destroy();
+		}
+		
+		return false;
     }
 
-	///// <summary>Kills the window in the most quick and unfriendly way.</summary>
-  //  public void Kill () {
-		//window.Destroy();
-    //}
-
-	/// <summary>Creates a new subtitles document for the specified path.</summary>
-	/// <param name="path">The subtitles' filename. If it's an empty string, 'Unsaved Subtitles' will be used instead.</param>
-	/// <remarks>If there's a document open with unsaved changes, a warning dialog is shown.</remarks>
+    /// <summary>Creates a new subtitles document for the specified path.</summary>
+    /// <param name="path">The subtitles' filename. If it's an empty string, 'Unsaved Subtitles' will be used instead.</param>
+    /// <remarks>If there's a document open with unsaved changes, a warning dialog is shown.</remarks>
     public void New () {
-    	if (!ToCreateNewAfterWarning())
-    		return;
-		else
+    		if (ToCreateNewAfterWarning()) {
 			Base.NewDocument();
+		}
     }
 
     /// <summary>Shows the open dialog and possibly opens a subtitle.</summary>
@@ -451,7 +456,7 @@ public class MainUi {
 		return true;
 	}
 
-	//FIXME use a header bar to show the title and subtitle
+	//TODO use a header bar to show the title and subtitle
 	private void UpdateTitleModificationStatus (bool showFilename, bool modified) {
 		if (showFilename) {
 			window.Title = (modified ? "*" : "") + Base.Document.TextFile.Filename;
@@ -464,9 +469,9 @@ public class MainUi {
 		switch (Base.Config.FileOpenEncoding) {
 			case ConfigFileOpenEncoding.CurrentLocale: return Encodings.SystemDefault.CodePage;
 			case ConfigFileOpenEncoding.Fixed:
-				string encodingName = Base.Config.FileOpenEncodingFixed;
+				string encodingCode = Base.Config.FileOpenEncodingFixed;
 				EncodingDescription encodingDescription = EncodingDescription.Empty;
-				Encodings.Find(encodingName, ref encodingDescription);
+				Encodings.Find(encodingCode, ref encodingDescription);
 				return encodingDescription.CodePage;
 			default: return -1; //Also accounts for Auto Detect
 		}
@@ -494,6 +499,30 @@ public class MainUi {
 
 		return file;
 	}
+	
+	private Builder ReadUIContent (string uiResourceName, string translationDomain) {
+		string content;
+	
+		using (Stream stream = Assembly.GetExecutingAssembly().GetManifestResourceStream(uiResourceName)) {
+			using (StreamReader reader = new StreamReader(stream, Encoding.UTF8)) {
+				content = reader.ReadToEnd();
+			}
+		}
+		
+		if (String.IsNullOrEmpty(content)) {
+			throw new Exception("Unable to read UI content from resource " + uiResourceName);
+		}
+
+		Builder builder = new Builder();
+		builder.TranslationDomain = translationDomain;
+		builder.AddFromString(content);
+
+		//Note: this doesn't work anymore. The translation domain needs to be set *before* loading the UI, but
+		//this gtk-sharp method is doing it *afterwards*.
+		//builder = new Builder(uiResourceName, Base.ExecutionContext.TranslationDomain);
+
+		return builder;
+	}
 
 
 	/* Event members */
