@@ -1,6 +1,6 @@
 /*
  * This file is part of Gnome Subtitles.
- * Copyright (C) 2008 Pedro Castro
+ * Copyright (C) 2008-2018 Pedro Castro
  *
  * Gnome Subtitles is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,6 +23,9 @@ namespace GnomeSubtitles.Ui.VideoPreview.Exceptions {
 
 public class PlayerCouldNotInitiateEngineException : ApplicationException {
 
+	public PlayerCouldNotInitiateEngineException (string message) : base(message) {
+	}
+
 }
 
 }
