@@ -1,6 +1,6 @@
 /*
  * This file is part of Gnome Subtitles.
- * Copyright (C) 2006-2017 Pedro Castro
+ * Copyright (C) 2006-2019 Pedro Castro
  *
  * Gnome Subtitles is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,9 +17,7 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-using GStreamer;
 using System;
-using System.IO;
 
 namespace GnomeSubtitles.Ui.VideoPreview {
 
@@ -82,8 +80,9 @@ public class PlayerPositionWatcher {
 	}
 
 	private void EmitPositionPulse (TimeSpan position) {
-		if (PositionPulse != null)
+		if (PositionPulse != null) {
 			PositionPulse(position);
+		}
 	}
 
 }
