@@ -1,6 +1,6 @@
 /*
  * This file is part of Gnome Subtitles.
- * Copyright (C) 2006-2018 Pedro Castro
+ * Copyright (C) 2006-2019 Pedro Castro
  *
  * Gnome Subtitles is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,14 +19,12 @@
 
 using Gdk;
 using GnomeSubtitles.Core;
-using GnomeSubtitles.Dialog.Unmanaged;
+using GnomeSubtitles.Dialog.Message;
 using Gtk;
 using GStreamer;
-using SubLib.Core;
 using SubLib.Core.Domain;
 using SubLib.Core.Timing;
 using System;
-using System.Text.RegularExpressions;
 
 namespace GnomeSubtitles.Ui.VideoPreview {
 
@@ -42,10 +40,6 @@ public class Video {
 	private bool isLoaded = false;
 	private bool playPauseToggleIsSilent = false; //Used to indicate whether toggling the button should not issue the toggled signal
 
-	/* Constants */
-	//private const string videoSetSubtitleStartIconFilename = "video-set-subtitle-start-16x.png";
-	//private const string videoSetSubtitleEndIconFilename = "video-set-subtitle-end-16x.png";
-	//private const string videoSetSubtitleStartEndIconFilename = "video-set-subtitle-start-end-30x.png";
 
 	public Video () {
 		videoArea = Base.GetWidget(WidgetNames.VideoAreaHBox) as Box;
@@ -53,9 +47,9 @@ public class Video {
 		InitializeVideoFrame();
 		InitializePlayer();
 
-		overlay = new SubtitleOverlay();
 		position = new VideoPosition(player);
 		tracker = new SubtitleTracker();
+		overlay = new SubtitleOverlay();
 
 		Base.InitFinished += OnBaseInitFinished;
 	}
@@ -98,6 +92,7 @@ public class Video {
 		get { return (player != null) && (player.HasVideo); }
 	}
 
+
 	/* Public methods */
 
 	public void Show () {
@@ -112,6 +107,8 @@ public class Video {
 	/// <exception cref="PlayerCouldNotOpenVideoException">Thrown if the player could not open the video.</exception>
 	public void Open (Uri videoUri) {
 		Close();
+		
+		frame.Show();
 
 		player.Open(videoUri);
 	}
@@ -123,24 +120,21 @@ public class Video {
 		isLoaded = false;
 
 		player.Close();
-		overlay.Close();
-		tracker.Close();
 		position.Disable();
-
+		tracker.Close();
+		overlay.Close();
 
 		/* Update the frame */
-//		frame.Child.Hide();
-//		frame.Child.Show();
-		frame.QueueDraw(); //To make sure the frame stops showing the last image from the closed video
 		frame.Ratio = Player.DefaultAspectRatio;
-
+		frame.Hide(); //To keep the frame from showing the last video image that was being played
+		
 		SilentDisablePlayPauseButton();
 		UpdateSpeedControls(1);
 		SetControlsSensitivity(false);
 	}
 
 	public void Quit () {
-		player.Close();
+		player.Dispose();
 	}
 
 	public void SetLoopSelectionPlayback (bool enabled){
@@ -288,8 +282,8 @@ public class Video {
 		}
 	}
 
-	private void handlePlayerLoading () {
-		if (isLoaded || (!isPlayerLoadComplete()))
+	private void HandlePlayerLoading () {
+		if (isLoaded || (!IsPlayerLoadComplete()))
 			return;
 
 		isLoaded = true;
@@ -297,7 +291,7 @@ public class Video {
 		Base.UpdateFromVideoLoaded(player.VideoUri);
 	}
 
-	private bool isPlayerLoadComplete () {
+	private bool IsPlayerLoadComplete () {
 		return (player != null) && (player.State != MediaStatus.Unloaded) && (player.HasVideoInfo) && (player.HasDuration);
 	}
 
@@ -323,17 +317,17 @@ public class Video {
 	}
 
 	private void OnPlayerFoundVideoInfo (VideoInfoEventArgs args) {
-		handlePlayerLoading();
+		HandlePlayerLoading();
 	}
 
 	private void OnPlayerStateChanged (StateEventArgs args) {
 		if (args.State == MediaStatus.Loaded) {
-			handlePlayerLoading();
+			HandlePlayerLoading();
 		}
 	}
 
 	private void OnPlayerFoundDuration (TimeSpan duration) {
-		handlePlayerLoading();
+		HandlePlayerLoading();
 	}
 
 	private void OnPlayerEndOfStream () {
@@ -361,11 +355,11 @@ public class Video {
 		if (!(Base.IsDocumentLoaded))
 			return;
 
-		Subtitle firstSubtitle = Core.Base.Ui.View.Selection.FirstSubtitle;
+		Subtitle firstSubtitle = Base.Ui.View.Selection.FirstSubtitle;
 		if (firstSubtitle == null)
 			return;
 
-		Subtitle lastSubtitle = Core.Base.Ui.View.Selection.LastSubtitle;
+		Subtitle lastSubtitle = Base.Ui.View.Selection.LastSubtitle;
 		if ((position < firstSubtitle.Times.Start) || (position > lastSubtitle.Times.End))
 			SeekToSelection();
 	}
