@@ -1,6 +1,6 @@
 /*
  * This file is part of Gnome Subtitles.
- * Copyright (C) 2006-2011 Pedro Castro
+ * Copyright (C) 2006-2018 Pedro Castro
  *
  * Gnome Subtitles is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@ public class WidgetNames {
 	public const string MainPaned = "mainPaned";
 
 	/* Menu Bar */
-	
+
 	/* File Menu */
 	public const string FileSave = "fileSave";
 	public const string FileSaveAs = "fileSaveAs";
@@ -34,11 +34,12 @@ public class WidgetNames {
 	public const string FileProperties = "fileProperties";
 	public const string FileTranslationNew = "fileTranslationNew";
 	public const string FileTranslationOpen = "fileTranslationOpen";
+	public const string FileTranslationReload = "fileTranslationReload";
 	public const string FileTranslationSave = "fileTranslationSave";
 	public const string FileTranslationSaveAs = "fileTranslationSaveAs";
 	public const string FileTranslationClose = "fileTranslationClose";
 	public const string FileClose = "fileClose";
-	
+
 	/* Edit Menu */
 	public const string EditUndo = "editUndo";
 	public const string EditRedo = "editRedo";
@@ -53,7 +54,7 @@ public class WidgetNames {
 	public const string EditDeleteSubtitles = "editDeleteSubtitles";
 	public const string EditSplit = "editSplit";
 	public const string EditMerge = "editMerge";
-	
+
 	/* View Menu */
 	public const string ViewTimes = "viewTimes";
 	public const string ViewFrames = "viewFrames";
@@ -61,7 +62,7 @@ public class WidgetNames {
 	public const string ViewVideo = "viewVideo";
 	public const string ViewVideoSubtitlesText = "viewVideoSubtitlesText";
 	public const string ViewVideoSubtitlesTranslation = "viewVideoSubtitlesTranslation";
-	
+
 	/* Search Menu */
 	public const string SearchFind = "searchFind";
 	public const string SearchFindNext = "searchFindNext";
@@ -70,11 +71,11 @@ public class WidgetNames {
 
 	/* Timings Menu */
 	public const string TimingsInputFrameRateMenu = "timingsInputFrameRateMenu";
-	public const string TimingsVideoFrameRateMenu = "timingsVideoFrameRateMenu";
+	public const string TimingsCurrentFrameRateMenu = "timingsCurrentFrameRateMenu";
 	public const string TimingsSynchronize = "timingsSynchronize";
 	public const string TimingsAdjust = "timingsAdjust";
 	public const string TimingsShift = "timingsShift";
-	
+
 	/* Video Menu */
 	public const string VideoClose = "videoClose";
 	public const string VideoPlayPause = "videoPlayPause";
@@ -87,13 +88,12 @@ public class WidgetNames {
 	public const string VideoLoopSelectionPlayback = "videoLoopSelectionPlayback";
 	public const string VideoSetSubtitleStart = "videoSetSubtitleStart";
 	public const string VideoSetSubtitleEnd = "videoSetSubtitleEnd";
-	
+
 	/* Tools Menu */
 	public const string ToolsAutocheckSpelling = "toolsAutocheckSpelling";
-	public const string ToolsSetTextLanguage = "toolsSetTextLanguage";
-	public const string ToolsSetTranslationLanguage = "toolsSetTranslationLanguage";
-	public const string ToolsTranslateText = "toolsTranslateText";
-	public const string ToolsTranslateTranslation = "toolsTranslateTranslation";
+	public const string ToolsSetLanguages = "toolsSetLanguages";
+	//public const string ToolsTranslateText = "toolsTranslateText";
+	//public const string ToolsTranslateTranslation = "toolsTranslateTranslation";
 
 
 	/* Toolbar */
@@ -109,21 +109,17 @@ public class WidgetNames {
 	public const string BoldButton = "boldToolButton";
 	public const string ItalicButton = "italicToolButton";
 	public const string UnderlineButton = "underlineToolButton";
-		
+
 	/* Video */
 	public const string VideoAreaHBox = "videoAreaHBox";
 	public const string VideoTimingsVBox = "videoTimingsVBox";
-	public const string VideoSubtitleLabel = "videoSubtitle";
-	public const string VideoSubtitleLabelEventBox = "videoSubtitleEventBox";
+	public const string VideoImageOverlay = "videoImageOverlay";
 	public const string VideoPositionLabel = "videoControlsPositionLabel";
 	public const string VideoPositionValueLabel = "videoControlsPositionValueLabel";
 	public const string VideoLengthValueLabel = "videoControlsLengthValueLabel";
 	public const string VideoSetSubtitleStartButton = "videoSetSubtitleStartButton";
-	public const string VideoSetSubtitleStartButtonImage = "videoSetSubtitleStartButtonImage";
 	public const string VideoSetSubtitleEndButton = "videoSetSubtitleEndButton";
-	public const string VideoSetSubtitleEndButtonImage = "videoSetSubtitleEndButtonImage";
 	public const string VideoSetSubtitleStartEndButton = "videoSetSubtitleStartEndButton";
-	public const string VideoSetSubtitleStartEndButtonImage = "videoSetSubtitleStartEndButtonImage";
 	public const string VideoFrame = "videoFrame";
 	public const string VideoPlaybackHBox = "videoPlaybackHBox";
 	public const string VideoSlider = "videoSlider";
@@ -138,7 +134,7 @@ public class WidgetNames {
 
 	/* Subtitle View */
 	public const string SubtitleView = "subtitleView";
-	
+
 	/* Subtitle Edit */
 	public const string SubtitleEdit = "subtitleEdit";
 	public const string StartSpinButton = "startSpinButton";
@@ -147,12 +143,12 @@ public class WidgetNames {
 	public const string SubtitleEditText = "subtitleEditText";
 	public const string SubtitleEditTranslation = "subtitleEditTranslation";
 	public const string SubtitleEditTranslationScrolledWindow = "subtitleEditTranslationScrolledWindow";
-	
+
 	/* Status Bar */
 	public const string MessageStatusbar = "messageStatusbar";
 	public const string PositionStatusbar = "positionStatusbar";
 	public const string OverwriteStatusbar = "overwriteStatusbar";
-	
+
 }
 
 }
