@@ -1,6 +1,6 @@
 /*
  * This file is part of SubLib.
- * Copyright (C) 2005-2017 Pedro Castro
+ * Copyright (C) 2005-2019 Pedro Castro
  *
  * SubLib is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,13 +17,11 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-using SubLib.Core;
 using SubLib.Core.Domain;
 using SubLib.Core.Timing;
 using SubLib.IO.SubtitleFormats;
 using System;
 using System.Globalization;
-using System.Text;
 using System.Text.RegularExpressions;
 
 namespace SubLib.IO.Input {
